Class: Geokit::Geocoders::CaGeocoder

Inherits:
Geocoder
  • Object
show all
Defined in:
lib/geokit/geocoders/ca_geocoder.rb

Overview

Geocoder CA geocoder implementation. Requires the Geokit::Geocoders::GEOCODER_CA variable to contain true or false based upon whether authentication is to occur. Conforms to the interface set by the Geocoder class.

Returns a response like:

49.243086 -123.153684

Method Summary

Methods inherited from Geocoder

call_geocoder_service, do_reverse_geocode, geocode, reverse_geocode